;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#xe245d6815ec5621351dd2cb3720def85 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xb15380976e95be2faf5041c792e26d15 . "./code.cg2js/cg-printing.fasl")
(#xf927b5ae9a667a9168d916eb18aba1b2 . "./code.cg2js/cg-caret.fasl")
(#x4a4ed7058b28758df9cb33f927251520 . "./code.cg2js/cg-item-list.fasl")
(#x9e76fab130bdf137bcada0b45ad5936d . "./code.cg2js/cg-progress-indicator.fasl")
(#x35ee9c86bed0e24528a021203a90c9f4 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x6b04327af9ecd1aafa7b5a0d01bcfe9a . "./code.cg2js/cg-outline.fasl")
(#xcb98dbea61625ef19db94e1f917c8a75 . "./code.cg2js/cg-palette.fasl")
(#xe42b4c44f80c8e818dceb52f1bd395c7 . "./code.cg2js/cg-selected-object.fasl")
(#xb42909b3d60a50f697a5d8573878db72 . "./code.cg2js/cg-status-bar.fasl")
(#xce3aac9e30163893d1d9bb40762f7645 . "./code.cg2js/cg-wrap-string.fasl")
(#xc8d7ce2d810425014b82abca3d48c952 . "./code.cg2js/cg-fill-texture.fasl")
(#x2ba35c379146576d84ee41ac238443a1 . "./code.cg2js/cg-layout.fasl")
(#x6441e246fae41f5b0b4354104e9ada71 . "./code.cg2js/cg-timer.fasl")
(#xb52241d50dc3f370b5ad597a22bdc3e3 . "./code.cg2js/cg-dialog-item.fasl")
(#x8275d3fc25a5d0414a62351d7cb68612 . "./code.cg2js/cg-button.fasl")
(#x1d5a243e1e7d3271d4c11725f0861409 . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#xaf9b7eee8d189850c76c55ee1a430bae . "./code.cg2js/cg-tray.fasl")
(#xaaa0ac3a62f5ec5a4ada7144525f90ab . "./code.cg2js/cg-plot-widget.fasl")
(#x8255197c91b6717ae8a4455717840d84 . "./code.cg2js/cg-pixmap.fasl")
(#xb74f54d1fbe2f93cab1f94041b2360e7 . "./code.cg2js/cg-font-dialog.fasl")
(#xb8943fa1eabccaf5ad294a88007dd169 . "./code.cg2js/cg-os-widget.fasl")
(#xfa85b65db7fdebb845cf91607ae94f91 . "./code.cg2js/cg-text-or-combo.fasl")
(#x0d5860414be98f217c3d0c8d1a48da40 . "./code.cg2js/cg-trackbar.fasl")
(#x0b455899304f70b60f4f81b86a446add . "./code.cg2js/cg-up-down-control.fasl")
(#x9002c188a9444bafb010cf1e6210af08 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#xe70285445b1ad040fd21bb572fcc4e90 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x3e1d2c5d6483ede15b694d2574a00055 . "./code.cg2js/cg-intersect-posbox.fasl")
(#x9c3a74b4e89a5df08b7edc265503e9e4 . "./code.cg2js/cg-bitmap-stream.fasl")
(#x6754be2af4602a00e497e9f475e15e26 . "./code.cg2js/cg-chart-widget.fasl")
(#xd316c5918e15fa37ac5c9ae5dfed9bc5 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#xc1e29282823d985db18d750e980608bf . "./code.cg2js/cg-group-box.fasl")
(#xc7fe20ece4427fb61c2fc18e2231c8e8 . "./code.cg2js/cg-static-text.fasl")
(#xb54949f3b98d44ebc15c906bae84fdc3 . "./code.cg2js/cg-class-slot-grid.fasl")
(#xf8e783f3172e4f131f28fadeb498f9d5 . "./code.cg2js/cg-color-dialog.fasl")
(#x4f2a1836de9a0d154a3ea972eba6daa9 . "./code.cg2js/cg-intersect.fasl")
(#xfea9082d14bea2bf1571f5c38f547c3a . "./code.cg2js/cg-gesture-emulation.fasl")
(#x68b72adbb1b8dfc6e10744f7d8162888 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x195b6e49b1f287c2574f1e157c588b6a . "./code.cg2js/cg-html-dialog.fasl")
(#x5bc07ff18fc75081a0447b02821c9024 . "./code.cg2js/cg-lettered-menu.fasl")
(#x69687ecd8d798785046dd05b1bea71a4 . "./code.cg2js/cg-class-grid.fasl")
(#xfe213b7b117519ad973bcb31ab5b2db4 . "./code.cg2js/cg-pixmap-printing.fasl")
(#x1f71fb5f4314becdc6c244af74296591 . "./code.cg2js/cg-calendar.fasl")
(#x49537b2e22a90cab9bfd29b3eade6406 . "./code.cg2js/cg-editable-text.fasl")
(#x456eef5ed02eb29f8e4200c1df919cf1 . "./code.cg2js/cg-property.fasl")
(#x7bc4747303116f4434d81d3c1cd78189 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#xcf9fd84a15477db5e3ffe6c73bf08703 . "./code.cg2js/cg-grid-widget.fasl")
(#xb7e8e4676afbe88a5796a595a3bd1bbe . "./code.cg2js/cg-paren-matching.fasl")
(#x86c120f61072dbacbd31029c49c8a9ce . "./code.cg2js/cg-dev.fasl")
(#x1e0dc1217a1f28592c95e6d8997658f9 . "./code.cg2js/cg-drawable.fasl")
(#xf5ffe4e95eb5b9131e292571c4ced3f0 . "./code.cg2js/cg-curve.fasl")
(#x90c74016b87541e4f69e3bdb239bc72d . "./code.cg2js/cg-lisp-widget.fasl")
(#x1a3b39948b2a8df8b854086bcb043a17 . "./code.cg2js/cg-dde-utils.fasl")
(#xcd0823663ded0c7259efb1dabf602ad1 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#xee9b49f0ab42897c4198a18e2cfe3df1 . "./code.cg2js/cg-object-editor-layout.fasl")
(#x8697802a44e7156167bc3aa42565d0ef . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#xfe1c161f9c766c346679b71a6a47ec34 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x6372e103bc6d2b11255c04a36fd15ab9 . "./code.cg2js/cg-lamp.fasl")
(#xad45ece9774953782f994db117f889c7 . "./code.cg2js/cg-common-control.fasl")
(#x1b4dd1e56ced17bc4cbfcaee5e87a9cc . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x81b4200dd04120ae9df8685b0b2d9a1f . "./code.cg2js/cg-directory-dialog-os.fasl")
(#xfb067280a8eed413f3e7bbbd09c02556 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#xddfd8cc0363eddb2b06090452d92a625 . "./code.cg2js/cg-project-window.fasl")
(#x32306d68604553885268f08d348db20a . "./code.cg2js/cg-sample-file-menu.fasl")
(#xf7609213a7ff070bc62b221f6de6d677 . "./code.cg2js/cg-class-support.fasl")
(#x768a850c866d62ebfe4f544ef9346540 . "./code.cg2js/cg-multi-picture-button.fasl")
(#x195893840398e31d9005d2a76f1592cc . "./code.cg2js/cg-yes-no-list.fasl")
(#x38e765df610f5d1d29615d2b1953abb5 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x98cf15d3b9468e57f85e2eab61946c61 . "./code.cg2js/cg-string-dialog.fasl")
(#x9c90eb4fce8cc92ff22c9beee7e37dc0 . "./code.cg2js/cg-menu-tooltip.fasl")
(#x2ff69c8488bb99db3013e63284ffac44 . "./code.cg2js/cg-dropping-outline.fasl")
(#x6f19f591946b1130a9999ae07a25c333 . "./code.cg2js/cg.fasl")
(#xfbbfb1e6e21fdca3dc71df9823576687 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x1cf99af948fe1dcae6c221dcbf63af94 . "./code.cg2js/cg-scaling-stream.fasl")
(#x6095ceb62b9622afd89e1028f878dfca . "./code.cg2js/cg-yes-no-string.fasl")
(#xbf9e71d1fbc9646f770f5679dbbfd3dd . "./code.cg2js/cg-icon-pixmap.fasl")
(#x5c471179659bff2b6c46b9ed04963794 . "./code.cg2js/cg-web-browser.fasl")
(#x6a26b68de44127a453c7d0f6a88b94bf . "./code.cg2js/cg-clipboard-stack.fasl")
(#x490b93f0b03a5bcbfee7076c9b644772 . "./code.cg2js/cg-drag-and-drop.fasl")
(#xb6036228e58ddd21e7a815cfab7a1e6a . "./code.cg2js/cg-message-dialog.fasl")
(#x0eee00102d7ed15092a253f4e50c110b . "./code.cg2js/cg-comtab.fasl")
(#x949ff272ee5377565eab5c70c2169605 . "./code.cg2js/cg-base.fasl")
(#x0aa7df85050cac7fbf897f672c3fbcac . "./code.cg2js/cg-pixmap-widget.fasl")
(#x5349f6e0b39996aa184f3cfabe833b5f . "./code.cg2js/cg-rich-edit-pane.fasl")
(#xbb977186397fb6b608de769929969fc6 . "./code.cg2js/cg-text-edit-pane.fasl")
(#x2a81bd557a90c7c34e2a0916d1719a08 . "./code.cg2js/cg-utility-dialog.fasl")
(#xeae586f13df8db266c376b4dc038d39c . "./code.cg2js/cg-object-editor.fasl")
(#x30c2f11391860d279141009da40db389 . "./code.cg2js/cg-edit-in-place.fasl")
(#x5080afd63a69ee9a675de3080e06aad2 . "./code.cg2js/cg-radio-button.fasl")
(#x4b1a7af92396db342e87b950fad1c4d2 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#xea0a315492dd03badd5c4d4561b05610 . "./code.cg2js/cg-nodes.fasl")
(#x729e50d3ff8345b5bb6306fa033c4113 . "./code.cg2js/cg-get-position.fasl")
(#x1e8bf84af26861dcfe59061abde18124 . "./code.cg2js/cg-directory-dialog.fasl")
(#x308b9324856771902d4fb095bd16ecb7 . "./code.cg2js/cg-lisp-text.fasl")
(#x31f855ce2389a67ea1d26157fd5f3a17 . "./code.cg2js/cg-combo-box.fasl")
(#xa3b93cef6bf71b35c61fccae5b501a6f . "./code.cg2js/cg-text-widget.fasl")
(#xd9b7b35c336fbbb6598738d98ddc0f44 . "./code.cg2js/cg-list-view.fasl")
(#x5a08f36becb135c71d41ade9781a894e . "./code.cg2js/cg-header-control.fasl")
(#x80c1dc72ca7043b9a36d818371143bf6 . "./code.cg2js/cg-graphics-context.fasl")
(#xfcea1f63a76aae5e7eaea160ee354b04 . "./code.cg2js/cg-get-pixmap.fasl")
(#x40a158f90634aa355a1e08e14cfe89e3 . "./code.cg2js/cg-menu.fasl")
(#xc44d934adaade6f363ad16e642b59daf . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x25dc7e6c90695ec45540b11cccbc1a95 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x2cd2e8f25395b19d10e55299f2fead67 . "./code.cg2js/cg-tooltip.fasl")
(#xeb02fb30dd3672be4b2477ad14811c17 . "./code.cg2js/cg-html-widget.fasl")
(#x334e5bba5a30d7a2c87895030b1ac42e . "./code.cg2js/cg-choice-list.fasl")
(#xf86728d3427945dcae77afb4790443d4 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x52b00d33ee897ee0a02092998a128363 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x9426766c93f86acfe4716f340d6d7618 . "./code.cg2js/cg-icon.fasl")
(#xa9076a0e667e656b5d1ef2bb8cf28073 . "./code.cg2js/cg-acache.fasl")
(#xe7c5b78ec83e19f554bd056de51ee345 . "./code.cg2js/cg-template-string.fasl")
(#xb1866ca4d54d8ec0211519bf8cefa2a8 . "./code.cg2js/cg-bitmap-pane.fasl")
(#xb9fe6ed4fd0af4bffee65b0f3c437f3b . "./code.cg2js/cg-toggling-widget.fasl")
(#x6d8c0f9a89bef2b02b8dc29d6e1fc5b7 . "./code.cg2js/cg-tab-control.fasl")
(#x311bf8e81306db8dd3c157704e138c7c . "./code.cg2js/cg-split-bar.fasl")
(#x2add02237d5c333b4cd0d20a9ecb7bbe . "./code.cg2js/cg-picture-widget.fasl")
(#x4ebc9601d20526515e3cfdfa30e53be1 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x93fadd158ed2e5389b7c1f1d0ef260cf . "./code.cg2js/cg-choose-printer.fasl")
(#x9b9dd607bdc36546e3d5dfe8ee606f49 . "./code.cg2js/cg-os-window.fasl")
(#xb9f63775d4581ee606afda497999b045 . "./code.cg2js/cg-scroll-bar.fasl")
(#x263e474a1f7e375ada727a78171771c3 . "./code.cg2js/cg-clipboard.fasl")
(#x39dd2bead7d752b75fba3b4212298866 . "./code.cg2js/cg-find-string-dialog.fasl")
(#x0c660c0d7f73e89da9eef32789052cd3 . "./code.cg2js/cg-hotspot.fasl")
(#x689f5f1be3967c2b86844ea7e9fa5e0b . "./code.cg2js/cg-rich-edit.fasl")
(#xa2a1706d41b26ed9ad5daa917a895871 . "./code.cg2js/cg-check-box.fasl")
(#x39d71d9b344cc2f49b69f1b51d3a25c3 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#xe9826395e8f7aa59943b07c9b24ce1a1 . "./code.cg2js/cg-file-dialog.fasl")
(#xc68e172c10d000f2dd23947073dc809f . "./code.cg2js/cg-toolbar.fasl")
(#x400f2a38e9722774faa8ba1546da17aa . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x53a312dad21082766daeb84cd82cfe98 . "./code.cg2js/cg-chart-or-plot.fasl")
(#x949e3eb8ac6faf66d69abb8bb65f2791 . "./code.cg2js/cg-shortcut-menu.fasl")
(#x9f2c47fcafd07656129ed3fcc0395057 . "./code.idejs/ide-project.fasl")
(#x5bd040eeca6b427a50c1c73de2c7f0eb . "./code.idejs/ide-intro.fasl")
(#xb126d6c86c5eba8fb0edac47d411858e . "./code.idejs/ide-find-in-files.fasl")
(#x1ec064613e2874d57c0040661da49ed9 . "./code.idejs/ide-grapher.fasl")
(#xdc23608115ac4eb6be1f54e5de505256 . "./code.idejs/ide-inspector.fasl")
(#xb3a5fe338397f0c8505ca4e6d289ffb1 . "./code.idejs/ide-editor.fasl")
(#xe84f73077391229a074e05696dd73c92 . "./code.idejs/ide-window-list.fasl")
(#xd9c7f711f3dd036ec9733c0b132b987d . "./code.idejs/ide-process-browser.fasl")
(#xeb028765dafb5bfb99596caf87cd4476 . "./code.idejs/ide-patch-dialog.fasl")
(#xd4a1a70a63597c1428965d6175b5d42e . "./code.idejs/ide-class-grapher.fasl")
(#x43d4427ac1c4409ea26076f46cb81f27 . "./code.idejs/ide-base.fasl")
(#x8a175c86a2d92029f92de3c6ab663632 . "./code.idejs/ide.fasl")
(#x0c85e307a9f76150dac8453737db5e75 . "./code.idejs/ide-trace.fasl")
(#x5d871e03621d3d8b3630bd9ec9601684 . "./code.idejs/ide-form.fasl")
(#x77109280fe3ae328d2aa4168b23b095a . "./code.idejs/ide-find-definitions.fasl")
(#x6b34b87bb6d1039ee27564529034a8c8 . "./code.idejs/ide-apropos.fasl")
(#x088ad6512e230b188e07bfee84b2c05e . "./code.idejs/ide-class-browser.fasl")
(#x702e7be3cfbefec0ede0de09131b3f29 . "./code.idejs/ide-navigator.fasl")
(#x841d2a31b0cb58ea7d5c40cd0baf2fd9 . "./code.idejs/ide-clipboard.fasl")
(#x8da00b3876dab813986d652ef1f265eb . "./code.idejs/ide-acache.fasl")
(#x9c7f723658efa85431f03bcceb38c684 . "./code.idejs/ide-keyshort.fasl")
(#xbe7282fc42881ab70267f10b5dc4b80c . "./code.idejs/ide-package-list.fasl")
(#x201ea78cd0a773aebb5e403396c96dec . "./code.idejs/ide-dev.fasl")
(#xb19a66ec109be5a69fb5293c577fc104 . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
